==> mozilla-source-0.7.tar.bz2: mozilla/xpinstall/wizard/windows/setuprsc/setuprsc.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by setuprsc.rc
//
#ifndef WINVER
#define WINVER 0x0400
#endif
#include "winresrc.h"
#define IDS_ERROR_DIALOG_CREATE         1
#define IDS_ERROR_FAILED                2
#define IDS_ERROR_FILE_NOT_FOUND        3
#define IDS_ERROR_GET_SYSTEM_DIRECTORY_FAILED 4
#define IDS_ERROR_GET_WINDOWS_DIRECTORY_FAILED 5
#define IDS_DLGQUITTITLE                6
#define IDS_DLGQUITMSG                  7
#define IDS_DLG_REBOOT_TITLE            8
#define IDS_ERROR_GETPROCADDRESS        9
#define IDS_ERROR_WRITEPRIVATEPROFILESTRING 10
#define IDS_MSG_RETRIEVE_CONFIGINI      11
#define IDS_ERROR_CREATE_TEMP_DIR       12
#define IDS_DLGBROWSETITLE              13
#define IDS_ERROR_DETERMINING_DISK_SPACE 14
#define IDS_DLG_DISK_SPACE_CHECK_TITLE  15
#define IDS_DLG_DISK_SPACE_CHECK_SYS_MSG 16
#define IDS_DLG_DISK_SPACE_CHECK_CRUTIAL_MSG 16
#define IDS_DLG_DISK_SPACE_CHECK_MSG    17
#define IDS_ERROR_CREATE_DIRECTORY      18
#define IDS_STR_FILE_NUMBER             19
#define IDS_STR_FILENAME                20
#define IDS_MSG_SMARTUPDATE_START       21
#define IDS_MSG_CONFIGURING             22
#define IDS_ERROR_XPI_INSTALL           23
#define IDS_ERROR_SETUP_REQUIREMENT     24
#define IDS_DLG_EXTRACTING_TITLE        25
#define IDS_STR_PROCESSINGFILE          26
#define IDS_STR_INSTALLING              27
#define IDS_STR_COPYINGFILE             28
#define IDS_MB_WARNING_STR              29
#define IDS_MB_MESSAGE_STR              30
#define IDI_ICON1                       105
#define IDI_SETUP                       105
#define IDB_BITMAP_WELCOME              108
#define DLG_MESSAGE                     110
#define DLG_BROWSE_DIR                  503
#define IDC_STATUS                      1001
#define IDC_STATUS1                     1001
#define ID_DELETE                       1001
#define IDC_GAUGE                       1002
#define IDC_GAUGE_FILE                  1002
#define ID_IGNORE                       1002
#define IDC_STATUS2                     1003
#define IDC_STATUS0                     1004
#define IDC_STATUS3                     1005
#define ID_YES_TO_ALL                   1005
#define IDC_GAUGE_ARCHIVE               1006
#define IDC_EDIT_DESTINATION            1009
#define IDC_BUTTON_BROWSE               1010
#define IDC_EDIT_COMPONENT1             1013
#define IDC_EDIT_SUBCOMPONENT           1014
#define IDC_STATIC_SUBCOMPONENT         1016
#define IDC_CHECK1                      1017
#define IDC_STATIC_DESCRIPTION          1018
#define IDC_EDIT_PROGRAM_FOLDER         1019
#define IDC_CHECK2                      1023
#define IDC_LIST2                       1023
#define IDC_LIST                        1023
#define IDC_CHECK3                      1024
#define IDC_EDIT_LICENSE                1024
#define IDC_CHECK0                      1025
#define IDC_CURRENT_SETTINGS            1026
#define IDC_LIST_COMPONENTS             1027
#define IDC_LIST_SUBCOMPONENTS          1029
#define IDC_STATIC_DRIVE_SPACE_REQUIRED 1030
#define IDC_SPACE_AVAILABLE             1030
#define IDC_STATIC_DRIVE_SPACE_AVAILABLE 1031
#define IDC_STATIC_DESTINATION          1032
#define IDC_STATIC0                     1033
#define IDC_STATIC1                     1034
#define IDC_STATIC2                     1035
#define IDC_MESSAGE1                    1040
#define IDC_PICT0                       1041
#define IDC_MESSAGE0                    1042
#define IDC_STATIC_ST0_DESCRIPTION      1042
#define IDC_STATIC_ST1_DESCRIPTION      1043
#define IDC_MESSAGE2                    1043
#define IDC_STATIC_ST2_DESCRIPTION      1044
#define IDC_STATIC_ST3_DESCRIPTION      1045
#define IDC_STATIC_MSG0                 1046
#define IDC_MESSAGE                     1049
#define IDC_LIST1                       1053
#define IDC_BUTTON1                     1055
#define IDC_README                      1055
#define IDC_BUTTON_SITE_SELECTOR        1055
#define IDC_DOWNLOAD_SIZE               1058
#define IDC_SITE_SELECTOR               1059
#define IDC_LIST_SITE_SELECTOR          1059
#define IDC_CHECK_SAVE_INSTALLER        1061
#define IDC_CHECK_SAVE_INSTALLER_FILES  1061
#define IDC_EDIT_PROXY_SERVER           1062
#define IDC_EDIT_PROXY_PORT             1063
#define IDC_TAB1                        1064
#define IDC_DELETE_PATH                 1065
#define IDC_LOCAL_INSTALLER_PATH        1066
#define IDC_EDIT_LOCAL_INSTALLER_PATH   1066
#define IDC_BUTTON_ADDITIONAL_SETTINGS  1067
#define IDC_BUTTON_PROXY_SETTINGS       1067
#define DLG_WELCOME                     2001
#define DLG_LICENSE                     2002
#define DLG_SETUP_TYPE                  2003
#define DLG_SELECT_COMPONENTS_SINGLE    2004
#define DLG_SELECT_COMPONENTS           2004
#define DLG_SELECT_COMPONENTS_MULTI     2005
#define DLG_WINDOWS_INTEGRATION         2006
#define DLG_PROGRAM_FOLDER              2007
#define DLG_START_INSTALL               2008
#define DLG_EXTRACTING                  2009
#define DLG_RESTART                     10206
#define DLG_SITE_SELECTOR               10207
#define DLG_ADVANCED_SETTINGS           10207
#define DLG_SELECT_ADDITIONAL_COMPONENTS 10208
#define DLG_UPGRADE                     10209
#define DLG_DOWNLOAD_OPTIONS            10210
#define IDB_BOX_CHECKED                 10304
#define IDB_BOX_UNCHECKED               10306
#define IDB_BOX_CHECKED_DISABLED        10307
#define IDC_RADIO_TYPICAL               11007
#define IDC_RADIO_ST0                   11007
#define IDC_RADIO_CUSTOM                11008
#define IDC_RADIO_ST2                   11008
#define IDC_RADIO_COMPACT               11009
#define IDC_RADIO_ST1                   11009
#define IDC_RADIO_ST3                   11010
#define IDC_RADIO_YES                   11011
#define IDC_RADIO_NO                    11012
#define IDWIZBACK                       11013
#define IDWIZNEXT                       11014
#define IDS_MSG_CREATE_DIRECTORY        11015
#define IDWIZNEXT2                      11015
#define IDS_STR_CREATE_DIRECTORY        11016
#define IDS_ERROR_PROGRAM_FOLDER_NAME   11017
#define IDS_CB_DEFAULT                  11018
#define IDS_ERROR_DESTINATION_PATH      11019
#define IDS_STR_SETUP_TYPE              11020
#define IDS_STR_SELECTED_COMPONENTS     11021
#define IDS_STR_DESTINATION_DIRECTORY   11022
#define IDS_STR_PROGRAM_FOLDER          11023
#define IDS_STR_DELETING_DESTINATION_DIR 11024
#define IDS_STR_SETUP                   11025
#define IDS_STR_DOWNLOAD_SITE           11026
#define IDS_STR_SAVE_INSTALLER_FILES    11027
#define IDS_MSG_INIT_SETUP              11028
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        112
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1070
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mozilla-source-0.9.1.tar.bz2: mozilla/xpinstall/wizard/windows/setuprsc/setuprsc.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by setuprsc.rc
//
#ifndef WINVER
#define WINVER 0x0400
#endif
#include "winresrc.h"
#define IDS_ERROR_FILE_NOT_FOUND        3
#define IDRESUME                        3
#define IDPAUSE                         4
#define IDS_MSG_RETRIEVE_INSTALLINI     11
#define IDI_ICON1                       105
#define IDI_SETUP                       105
#define IDB_BITMAP_WELCOME              108
#define DLG_MESSAGE                     110
#define IDB_BITMAP_DOWNLOAD_LOGO        114
#define DLG_BROWSE_DIR                  503
#define IDC_STATUS                      1001
#define IDC_STATUS1                     1001
#define ID_DELETE                       1001
#define IDC_STATUS_URL                  1001
#define IDC_GAUGE                       1002
#define IDC_GAUGE_FILE                  1002
#define ID_IGNORE                       1002
#define IDC_STATUS2                     1003
#define IDC_STATUS_URL2                 1003
#define IDC_STATUS_TO                   1003
#define IDC_STATUS0                     1004
#define IDC_STATUS3                     1005
#define ID_YES_TO_ALL                   1005
#define IDC_STATUS_URL3                 1005
#define IDC_GAUGE_ARCHIVE               1006
#define IDC_EDIT_DESTINATION            1009
#define IDC_BUTTON_BROWSE               1010
#define IDC_EDIT_COMPONENT1             1013
#define IDC_EDIT_SUBCOMPONENT           1014
#define IDC_STATIC_SUBCOMPONENT         1016
#define IDC_CHECK1                      1017
#define IDC_STATIC_DESCRIPTION          1018
#define IDC_EDIT_PROGRAM_FOLDER         1019
#define IDC_CHECK2                      1023
#define IDC_LIST2                       1023
#define IDC_LIST                        1023
#define IDC_CHECK3                      1024
#define IDC_EDIT_LICENSE                1024
#define IDC_CHECK0                      1025
#define IDC_CURRENT_SETTINGS            1026
#define IDC_LIST_COMPONENTS             1027
#define IDC_LIST_SUBCOMPONENTS          1029
#define IDC_STATIC_DRIVE_SPACE_REQUIRED 1030
#define IDC_SPACE_AVAILABLE             1030
#define IDC_STATIC_DRIVE_SPACE_AVAILABLE 1031
#define IDC_STATIC_DESTINATION          1032
#define IDC_STATIC0                     1033
#define IDC_STATIC1                     1034
#define IDC_STATIC2                     1035
#define IDC_STATIC3                     1036
#define IDC_STATIC4                     1037
#define IDC_PERCENTAGE                  1038
#define IDC_MESSAGE1                    1040
#define IDC_PICT0                       1041
#define IDC_MESSAGE0                    1042
#define IDC_STATIC_ST0_DESCRIPTION      1042
#define IDC_STATIC_ST1_DESCRIPTION      1043
#define IDC_MESSAGE2                    1043
#define IDC_STATIC_ST2_DESCRIPTION      1044
#define IDC_STATIC_ST3_DESCRIPTION      1045
#define IDC_STATIC_MSG0                 1046
#define IDC_MESSAGE                     1049
#define IDC_LIST1                       1053
#define IDC_BUTTON1                     1055
#define IDC_README                      1055
#define IDC_BUTTON_SITE_SELECTOR        1055
#define IDC_DOWNLOAD_SIZE               1058
#define IDC_SITE_SELECTOR               1059
#define IDC_LIST_SITE_SELECTOR          1059
#define IDC_CHECK_SAVE_INSTALLER        1061
#define IDC_CHECK_SAVE_INSTALLER_FILES  1061
#define IDC_EDIT_PROXY_SERVER           1062
#define IDC_EDIT_PROXY_PORT             1063
#define IDC_TAB1                        1064
#define IDC_EDIT_PROXY_USER             1064
#define IDC_DELETE_PATH                 1065
#define IDC_EDIT_PROXY_PASSWD           1065
#define IDC_LOCAL_INSTALLER_PATH        1066
#define IDC_EDIT_LOCAL_INSTALLER_PATH   1066
#define IDC_BUTTON_ADDITIONAL_SETTINGS  1067
#define IDC_BUTTON_PROXY_SETTINGS       1067
#define IDC_STATUS_FILE                 1070
#define IDC_STATUS_STATUS               1071
#define IDC_USE_HTTP                    1073
#define IDC_USE_FTP                     1074
#define IDC_DESTINATION                 1074
#define DLG_WELCOME                     2001
#define DLG_LICENSE                     2002
#define DLG_SETUP_TYPE                  2003
#define DLG_SELECT_COMPONENTS_SINGLE    2004
#define DLG_SELECT_COMPONENTS           2004
#define DLG_SELECT_COMPONENTS_MULTI     2005
#define DLG_WINDOWS_INTEGRATION         2006
#define DLG_PROGRAM_FOLDER              2007
#define DLG_START_INSTALL               2008
#define DLG_EXTRACTING                  2009
#define DLG_RESTART                     10206
#define DLG_SITE_SELECTOR               10207
#define DLG_ADVANCED_SETTINGS           10207
#define DLG_SELECT_ADDITIONAL_COMPONENTS 10208
#define DLG_UPGRADE                     10209
#define DLG_DOWNLOAD_OPTIONS            10210
#define DLG_DOWNLOADING                 10211
#define IDB_BOX_CHECKED                 10304
#define IDB_BOX_UNCHECKED               10306
#define IDB_BOX_CHECKED_DISABLED        10307
#define IDC_RADIO_TYPICAL               11007
#define IDC_RADIO_ST0                   11007
#define IDC_RADIO_CUSTOM                11008
#define IDC_RADIO_ST2                   11008
#define IDC_RADIO_COMPACT               11009
#define IDC_RADIO_ST1                   11009
#define IDC_RADIO_ST3                   11010
#define IDC_RADIO_YES                   11011
#define IDC_RADIO_NO                    11012
#define IDWIZBACK                       11013
#define IDWIZNEXT                       11014
#define IDS_MSG_CREATE_DIRECTORY        11015
#define IDWIZNEXT2                      11015
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        115
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1075
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
